Transaction

Struct Transaction 

pub struct Transaction {
Show 17 fields pub type: Option<TransactionType>, pub nonce: Option<U256>, pub to: Address, pub gas: Option<U256>, pub block_hash: Option<H256>, pub block_number: Option<U256>, pub gas_price: Option<U256>, pub hash: Option<H256>, pub value: Option<U256>, pub input: Bytecode, pub max_priority_fee_per_gas: Option<U256>, pub max_fee_per_gas: Option<U256>, pub access_list: Option<AccessList>, pub chain_id: Option<U256>, pub v: Option<U256>, pub r: Option<U256>, pub s: Option<U256>, /* private fields */
}

Fields

type: Option<TransactionType>

transaction type

  1. Legacy (pre-EIP2718) 0x00
  2. EIP2930 (state access lists) 0x01
  3. EIP1559 0x02
nonce: Option<U256>

transaction nonce

to: Address

To address

gas: Option<U256>

Gas limit

block_hash: Option<H256>

Block hash

block_number: Option<U256>

Block number

gas_price: Option<U256>

Gas limit

hash: Option<H256>

Transaction hash

value: Option<U256>

Transfer eth value

input: Bytecode

Input data to call contract.

max_priority_fee_per_gas: Option<U256>

Maximum fee per gas the sender is willing to pay to miners in wei

max_fee_per_gas: Option<U256>

Maximum total fee per gas the sender is willing to pay(includes the network/base fee and miner/ priority fee) in wei

access_list: Option<AccessList>

EIP-2930 access list

chain_id: Option<U256>

Chain ID tha this transaction is valid on

v: Option<U256>

The parity(0 for even, 1 for odd) of the y-value of the secp256k1 signature.

r: Option<U256>

r-value of the secp256k1

s: Option<U256>

s-value of the secp256k1