EIP712Domain

Struct EIP712Domain 

pub struct EIP712Domain {
    pub name: Option<String>,
    pub version: Option<String>,
    pub chain_id: Option<Uint>,
    pub verifying_contract: Option<Address>,
    pub salt: Option<[u8; 32]>,
}
Eip712 Domain attributes used in determining the domain separator; Unused fields are left out of the struct type.

Protocol designers only need to include the fields that make sense for their signing domain. Unused fields are left out of the struct type.

Fields

name: Option<String>

The user readable name of signing domain, i.e. the name of the DApp or the protocol.

version: Option<String>

The current major version of the signing domain. Signatures from different versions are not compatible.

chain_id: Option<Uint>

The EIP-155 chain id. The user-agent should refuse signing if it does not match the currently active chain.

verifying_contract: Option<Address>

The address of the contract that will verify the signature.

salt: Option<[u8; 32]>

A disambiguating salt for the protocol. This can be used as a domain separator of last resort.

Implementations

Source

impl EIP712Domain

pub fn separator(&self) -> [u8; 32]