pub struct TypedData {
pub domain: EIP712Domain,
pub types: Types,
pub primary_type: String,
pub message: BTreeMap<String, Value>,
}Expand description
Typed data is a JSON object containing type information, domain separator parameters and the message object which has the following schema
{Fields
domain: EIP712DomainSigning domain metadata. The signing domain is the intended context for the signature (e.g. the dapp, protocol, etc. that it’s intended for). This data is used to construct the domain seperator of the message.
types: TypesThe custom types used by this message.
primary_type: StringThe type of the message.
message: BTreeMap<String, Value>The message to be signed.